==> igniteui-react-16.16.2.tgz: package/esm2015/lib/Radio.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { RadioLabelPosition_$type } from "./RadioLabelPosition";
import { ComponentBoolValueChangedEventArgs } from "./ComponentBoolValueChangedEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let Radio = /*@__PURE__*/ (() => {
    class Radio extends BaseElement {
        constructor() {
            super(...arguments);
            this.e = new WCNativeHelper();
            this.k = null;
            this.change = null;
            this.focus = null;
            this.blur = null;
        }
        get f() {
            return this.e;
        }
        get nativeElement() {
            return this.k;
        }
        set nativeElement(a) {
            this.k = a;
            this.e.d = this.k;
        }
        get n() {
            let ret_ = this.f.c("name");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.f.i("name", value_);
        }
        get o() {
            let ret_ = this.f.c("value");
            return ret_;
        }
        set o(a) {
            let value_ = a;
            this.f.i("value", value_);
        }
        get j() {
            let ret_ = this.f.c("required");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.f.i("required", value_);
        }
        get g() {
            let ret_ = this.f.c("checked");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.f.i("checked", value_);
        }
        get h() {
            let ret_ = this.f.c("disabled");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.f.i("disabled", value_);
        }
        get i() {
            let ret_ = this.f.c("invalid");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.f.i("invalid", value_);
        }
        get b() {
            let ret_ = this.f.c("labelPosition");
            ret_ = enumGetBox(RadioLabelPosition_$type, EnumUtil.getEnumValue(RadioLabelPosition_$type, EnumUtil.parse(RadioLabelPosition_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(RadioLabelPosition_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(RadioLabelPosition_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("labelPosition", value_);
        }
        get m() {
            let ret_ = this.f.c("ariaLabelledby");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.f.i("ariaLabelledby", value_);
        }
        changeChanged() {
            if (this.change != null) {
                this.f.g("change", (a) => this.change(this, ComponentBoolValueChangedEventArgs.a(a)));
            }
            else {
                this.f.h("change");
            }
        }
        focusChanged() {
            if (this.focus != null) {
                this.f.g("focus", (a) => this.focus(this, VoidEventArgs.b(a)));
            }
            else {
                this.f.h("focus");
            }
        }
        blurChanged() {
            if (this.blur != null) {
                this.f.g("blur", (a) => this.blur(this, VoidEventArgs.b(a)));
            }
            else {
                this.f.h("blur");
            }
        }
        s() {
            this.nativeElement.click();
        }
        t() {
            this.nativeElement.connectedCallback();
        }
        u() {
            this.nativeElement.disconnectedCallback();
        }
        w(a) {
            this.nativeElement.focusComponent(a);
        }
        q() {
            this.nativeElement.blurComponent();
        }
        x() {
            this.nativeElement.reportValidity();
        }
        y(a) {
            this.nativeElement.setCustomValidity(a);
        }
    }
    Radio.$t = /*@__PURE__*/ markType(Radio, 'Radio', BaseElement.$);
    return Radio;
})();

==> igniteui-react-18.6.0.tgz: package/esm2015/lib/Radio.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { RadioLabelPosition_$type } from "./RadioLabelPosition";
import { ComponentBoolValueChangedEventArgs } from "./ComponentBoolValueChangedEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let Radio = /*@__PURE__*/ (() => {
    class Radio extends BaseElement {
        constructor() {
            super(...arguments);
            this.e = new WCNativeHelper();
            this.k = null;
            this.change = null;
            this.focus = null;
            this.blur = null;
        }
        get f() {
            return this.e;
        }
        get nativeElement() {
            return this.k;
        }
        set nativeElement(a) {
            this.k = a;
            this.e.o = this.k;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get n() {
            let ret_ = this.f.n("value");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.f.v("value", value_);
        }
        get g() {
            let ret_ = this.f.n("checked");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.f.v("checked", value_);
        }
        get b() {
            let ret_ = this.f.n("labelPosition");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(RadioLabelPosition_$type, EnumUtil.getEnumValue(RadioLabelPosition_$type, this.f.f(RadioLabelPosition_$type, ret_)));
            return EnumUtil.getEnumValue(RadioLabelPosition_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(RadioLabelPosition_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.f.v("labelPosition", value_);
        }
        get h() {
            let ret_ = this.f.n("disabled");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.f.v("disabled", value_);
        }
        get j() {
            let ret_ = this.f.n("required");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.f.v("required", value_);
        }
        get m() {
            let ret_ = this.f.n("name");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.f.v("name", value_);
        }
        get i() {
            let ret_ = this.f.n("invalid");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.f.v("invalid", value_);
        }
        changeChanged() {
            if (this.change != null) {
                this.f.r("change", (a) => this.change(this, ComponentBoolValueChangedEventArgs.a(a)));
            }
            else {
                this.f.u("change");
            }
        }
        focusChanged() {
            if (this.focus != null) {
                this.f.r("focus", (a) => this.focus(this, VoidEventArgs.b(a)));
            }
            else {
                this.f.u("focus");
            }
        }
        blurChanged() {
            if (this.blur != null) {
                this.f.r("blur", (a) => this.blur(this, VoidEventArgs.b(a)));
            }
            else {
                this.f.u("blur");
            }
        }
        s() {
            this.nativeElement.click();
        }
        u(a) {
            this.nativeElement.focus(this.f.i(a));
        }
        p() {
            this.nativeElement.blur();
        }
        w(a) {
            this.nativeElement.setCustomValidity(this.f.i(a));
        }
        v() {
            this.nativeElement.reportValidity();
        }
        r() {
            this.nativeElement.checkValidity();
        }
    }
    Radio.$t = /*@__PURE__*/ markType(Radio, 'Radio', BaseElement.$);
    return Radio;
})();
